==> orgApp-0.0.1.tar.gz: orgApp-0.0.1/README.md <==
# orgApp
## personal organizing tool

<pre>
                                    .o.                             
                                   .888.                            
 .ooooo.  oooo d8b  .oooooooo     .8"888.     oo.ooooo.  oo.ooooo.  
d88' `88b `888""8P 888' `88b     .8' `888.     888' `88b  888' `88b 
888   888  888     888   888    .88ooo8888.    888   888  888   888 
888   888  888     `88bod8P'   .8'     `888.   888   888  888   888 
`Y8bod8P' d888b    `8oooooo.  o88o     o8888o  888bod8P'  888bod8P' 
================== d"     YD ================= 888 ====== 888 ===== 
                   "Y88888P'                  o888o      o888o      
</pre>

### to install `orgApp` package:

* clone this repository
* browse in terminal to root folder which contain `setup.py`
* use `pip install .` or `pip install -e .` command in terminal

It will install `orgApp` python packages.


### for running programs use:

#### Use next commands in terminal anywhere:

#### command `orgapp` to run main 'orgApp' application.

#### command `abk` or `addressbook` to run 'adress_book' application.

#### command `nbk` or `notebook` to run main 'note_book' manager.

#### command `sorter` to run 'sorter' application.

#### and commands `bandergoose` or `hannoitower` or `snake` or `tictactoe` to run relevant GUI game.

#### Then follow printed instructions.
###

[![Language](https://img.shields.io/badge/language-python-blue?&style=plastic)](https://www.python.org)
[![Language version](https://img.shields.io/badge/version-3.10-red?&style=plastic)](https://www.python.org/downloads/)
![GitHub repo size](https://img.shields.io/badge/repo%20size-340%20kB-pink?&style=plastic)
![GitHub followers](https://img.shields.io/github/followers/Vskesha?style=plastic)


---

### Technology which used:
[![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)](https://www.python.org)
[![Git](https://img.shields.io/badge/git-%23F05033.svg?style=for-the-badge&logo=git&logoColor=white)](https://git-scm.com/)
[![GitHub](https://img.shields.io/badge/github-%23121011.svg?style=for-the-badge&logo=github&logoColor=white)](https://github.com/)
![Markdown](https://img.shields.io/badge/markdown-%23000000.svg?style=for-the-badge&logo=markdown&logoColor=white)


**We used the following technologies and packages**

- Python
- Git
- Packages: pathlib, sys, tkinter, pygame, prompt_toolkit

==> orgApp-0.0.2.tar.gz: orgApp-0.0.2/README.md <==
# orgApp
## personal organizing tool

<pre>
                                    .o.                             
                                   .888.                            
 .ooooo.  oooo d8b  .oooooooo     .8"888.     oo.ooooo.  oo.ooooo.  
d88' `88b `888""8P 888' `88b     .8' `888.     888' `88b  888' `88b 
888   888  888     888   888    .88ooo8888.    888   888  888   888 
888   888  888     `88bod8P'   .8'     `888.   888   888  888   888 
`Y8bod8P' d888b    `8oooooo.  o88o     o8888o  888bod8P'  888bod8P' 
================== d"     YD ================= 888 ====== 888 ===== 
                   "Y88888P'                  o888o      o888o      
</pre>
With this app You can deal with your notes and contacts  
Use `nbk` or `notebook` command to open your notebook manager.<br>
Type `abk` or `addressbook` below to manage your contacts.<br>
Also You are able to sort your files with `sorter`.<br>
And if you are tired you can play simple games:<br>
`tictactoe`, `bandergoose`, `hannoitower` or `snake`.<br>

### to install `orgApp` package run `pip install orgApp`:<br> 
### or
* clone this repository https://github.com/Vskesha/orgApp.git
* browse in terminal to root folder which contain `setup.py`
* use `pip install .` or `pip install -e .` command in terminal

It will install `orgApp` python package to your system.


### for running programs use:

#### Use next commands in terminal anywhere:

#### command `orgapp` to run main 'orgApp' application.

#### command `abk` or `addressbook` to run 'adress_book' application.

#### command `nbk` or `notebook` to run main 'note_book' manager.

#### command `sorter` to run 'sorter' application.

#### and commands `bandergoose` or `hannoitower` or `snake` or `tictactoe` to run relevant GUI game.


###

[![Language](https://img.shields.io/badge/language-python-blue?&style=plastic)](https://www.python.org)
[![Language version](https://img.shields.io/badge/version-3.10-red?&style=plastic)](https://www.python.org/downloads/)
![GitHub repo size](https://img.shields.io/badge/repo%20size-340%20kB-pink?&style=plastic)
![GitHub followers](https://img.shields.io/github/followers/Vskesha?style=plastic)


---

### Technology which used:
[![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)](https://www.python.org)
[![Git](https://img.shields.io/badge/git-%23F05033.svg?style=for-the-badge&logo=git&logoColor=white)](https://git-scm.com/)
[![GitHub](https://img.shields.io/badge/github-%23121011.svg?style=for-the-badge&logo=github&logoColor=white)](https://github.com/)
![Markdown](https://img.shields.io/badge/markdown-%23000000.svg?style=for-the-badge&logo=markdown&logoColor=white)


- Technologies
  -
  - Python
  - Git
  - MarkDown

- Packages: 
  - 
  - calendar, collections, colorama, datetime,
  - functools, json, os, pygame, pathlib,
  - prompt_toolkit, random, Faker,
  - re, shutil, sys, textwrap, time
  - tkinter, prompt_toolkit
